---
title: FinnGen
---

<p align="center">
  <img width="300" height="200" src="../../../../assets/imgs/finngen.svg">
</p>
<style>
  .md-typeset h1,
  .md-content__button {
    display: none;
  }
</style>

[FinnGen](https://www.finngen.fi/en) is a research project in genomics and personalized medicine, representing a large public-private partnership. The project has collected and analyzed genome and health data from 500,000 Finnish biobank donors to understand the genetic basis of diseases. FinnGen is now expanding its focus to comprehend the progression and biological mechanisms of diseases. This initiative provides a world-class resource for further breakthroughs in disease prevention, diagnosis, and treatment, offering insights into our genetic makeup.

For a comprehensive understanding of the dataset and methods, refer to [Kurki et al., 2023](https://www.nature.com/articles/s41586-022-05473-8).

We ingested full GWAS summary statistics and SuSiE-based fine-mapping results.
